@@ -46,7 +46,7 @@ installations <- function(data = 'all', uuid = NULL, query = NULL,
 
   # Define function to get data
   getdata <- function(x){
-    if (!data %in% c('all','deleted', 'nonPublishing') && is.null(uuid))
+    if (!all(data %in% c('all','deleted', 'nonPublishing')) && is.null(uuid))
       stop('You must specify a uuid if data does not equal "all" and data
            does not equal one of deleted or nonPublishing', call. = FALSE)
 
