@@ -143,7 +143,7 @@ test_that("scientificName basic use works - no synonyms", {
   expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
   expect_equal(bb$data$species[1], "Pulsatilla patens")
   expect_equal(bb$data$scientificName[1],
-    "Anemone patens subsp. multifida (Pritzel) Hult\u00e9n")
+    "Pulsatilla nuttalliana (DC.) Spreng.")
 
   expect_is(cc, "gbif_data")
   expect_is(cc$data, "data.frame")
@@ -280,29 +280,6 @@ test_that("geometry inputs work as expected", {
   }, preserve_exact_body_bytes = TRUE)
 })
 
-######### spell check works
-test_that("spell check param works", {
-  vcr::use_cassette("occ_data_spellcheck", {
-    # as normal
-    expect_is(
-      occ_data(search = "kingfisher", limit=1, spellCheck = TRUE),
-      "gbif_data"
-    )
-
-    # spelled incorrectly - stops with suggested spelling
-    expect_error(
-      occ_data(search = "kajsdkla", limit=20, spellCheck = TRUE),
-      "spelling bad - suggestions"
-    )
-
-    # spelled incorrectly - stops with many suggested spellings and number of results for each
-    expect_error(
-      occ_data(search = "helir", limit=20, spellCheck = TRUE),
-      "spelling bad - suggestions"
-    )
-  })
-})
-
 # many args
 test_that("works with parameters that allow many inputs", {
   vcr::use_cassette("occ_data_args_with_many_inputs", {
